import { useState } from "react";
import { Link, useLocation } from "wouter";
import { Menu, X, ChevronDown } from "lucide-react";
import { Button } from "@/components/ui/button";

const Navigation = () => {
  const [location] = useLocation();
  const [mobileMenuOpen, setMobileMenuOpen] = useState(false);
  const [paidMediaOpen, setPaidMediaOpen] = useState(false);
  const [earnedMediaOpen, setEarnedMediaOpen] = useState(false);

  const navigation = [
    { name: "Home", href: "/" },
    { 
      name: "Paid Media", 
      href: "/paid-media",
      dropdown: [
        { name: "Paid Search", href: "/paid-search" },
        { name: "Paid Social", href: "/paid-social" }
      ]
    },
    { 
      name: "Earned Media", 
      href: "/earned-media",
      dropdown: [
        { name: "Organic Social", href: "/organic-social" },
        { name: "Content Marketing", href: "/content-marketing" }
      ]
    },
    { name: "Web Development", href: "/web-development" },
    { name: "Our Results", href: "/our-results" },
    { name: "Blog", href: "/blog" },
    { name: "Contact", href: "/contact" },
  ];

  const isActive = (href: string) => {
    if (href === "/" && location === "/") return true;
    if (href !== "/" && location.startsWith(href)) return true;
    return false;
  };

  const isDropdownActive = (dropdown: any[]) => {
    return dropdown.some(item => isActive(item.href));
  };

  return (
    <nav className="fixed top-0 w-full bg-white/95 backdrop-blur-sm z-50 border-b border-gray-100">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="flex justify-between items-center h-16">
          <div className="flex-shrink-0">
            <Link href="/">
              <h1 className="text-2xl font-bold font-poppins text-secondary cursor-pointer">
                Wassp<span className="text-primary">.</span>
              </h1>
            </Link>
          </div>
          
          <div className="hidden lg:block">
            <div className="ml-6 flex items-baseline space-x-4 xl:space-x-6">
              {navigation.map((item) => (
                <div key={item.name} className="relative">
                  {item.dropdown ? (
                    <div
                      className="relative"
                      onMouseEnter={() => {
                        if (item.name === "Paid Media") setPaidMediaOpen(true);
                        if (item.name === "Earned Media") setEarnedMediaOpen(true);
                      }}
                      onMouseLeave={() => {
                        if (item.name === "Paid Media") setPaidMediaOpen(false);
                        if (item.name === "Earned Media") setEarnedMediaOpen(false);
                      }}
                    >
                      <Link href={item.href}>
                        <span
                          className={`font-medium transition-colors duration-200 cursor-pointer flex items-center ${
                            isActive(item.href) || isDropdownActive(item.dropdown)
                              ? "text-secondary"
                              : "text-gray-600 hover:text-accent"
                          }`}
                        >
                          {item.name}
                          <ChevronDown className="ml-1 h-4 w-4" />
                        </span>
                      </Link>
                      
                      {/* Dropdown Menu */}
                      {((item.name === "Paid Media" && paidMediaOpen) || 
                        (item.name === "Earned Media" && earnedMediaOpen)) && (
                        <div className="absolute top-full left-0 w-48 z-50">
                          <div className="h-2"></div>
                          <div className="bg-white rounded-md shadow-lg border border-gray-100 py-2">
                            {item.dropdown.map((subItem) => (
                              <Link key={subItem.name} href={subItem.href}>
                                <span
                                  className={`block px-4 py-2 text-sm font-medium transition-colors duration-200 cursor-pointer ${
                                    isActive(subItem.href)
                                      ? "text-secondary bg-gray-50"
                                      : "text-gray-600 hover:text-accent hover:bg-gray-50"
                                  }`}
                                >
                                  {subItem.name}
                                </span>
                              </Link>
                            ))}
                          </div>
                        </div>
                      )}
                    </div>
                  ) : (
                    <Link href={item.href}>
                      <span
                        className={`font-medium transition-colors duration-200 cursor-pointer ${
                          isActive(item.href)
                            ? "text-secondary"
                            : "text-gray-600 hover:text-accent"
                        }`}
                      >
                        {item.name}
                      </span>
                    </Link>
                  )}
                </div>
              ))}
            </div>
          </div>
          
          <div className="lg:hidden">
            <Button
              variant="ghost"
              size="sm"
              onClick={() => setMobileMenuOpen(!mobileMenuOpen)}
              className="text-secondary"
              aria-label={mobileMenuOpen ? "Close mobile menu" : "Open mobile menu"}
              aria-expanded={mobileMenuOpen}
              aria-controls="mobile-menu"
            >
              {mobileMenuOpen ? <X size={24} /> : <Menu size={24} />}
            </Button>
          </div>
        </div>
      </div>
      
      {/* Mobile menu */}
      {mobileMenuOpen && (
        <div id="mobile-menu" className="lg:hidden bg-white border-t border-gray-100">
          <div className="px-2 pt-2 pb-3 space-y-1 sm:px-3">
            {navigation.map((item) => (
              <div key={item.name}>
                <Link href={item.href}>
                  <span
                    className={`block px-3 py-2 font-medium transition-colors duration-200 cursor-pointer ${
                      isActive(item.href) || (item.dropdown && isDropdownActive(item.dropdown))
                        ? "text-secondary"
                        : "text-gray-600 hover:text-accent"
                    }`}
                    onClick={() => setMobileMenuOpen(false)}
                  >
                    {item.name}
                  </span>
                </Link>
                {item.dropdown && (
                  <div className="ml-4 space-y-1">
                    {item.dropdown.map((subItem) => (
                      <Link key={subItem.name} href={subItem.href}>
                        <span
                          className={`block px-3 py-2 text-sm font-medium transition-colors duration-200 cursor-pointer ${
                            isActive(subItem.href)
                              ? "text-secondary"
                              : "text-gray-500 hover:text-accent"
                          }`}
                          onClick={() => setMobileMenuOpen(false)}
                        >
                          {subItem.name}
                        </span>
                      </Link>
                    ))}
                  </div>
                )}
              </div>
            ))}
          </div>
        </div>
      )}
    </nav>
  );
};

export default Navigation;
